@@ -11,6 +11,7 @@ pub struct Standup {
     pub doing: Vec<String>,
     pub blockers: Vec<String>,
     pub sidebars: Vec<String>,
+    pub history: Vec<String>,
 }
 
 impl Standup {
@@ -20,21 +21,47 @@ impl Standup {
             doing: Vec::new(),
             blockers: Vec::new(),
             sidebars: Vec::new(),
+            history: Vec::new(),
         }
     }
 
     pub fn add_item(mut self, file: &Path, command: &str, item: &str) {
         match command {
-            DID | DI => self.did.push(String::from(item)),
-            DOING | DO => self.doing.push(String::from(item)),
-            BLOCKER | BL => self.blockers.push(String::from(item)),
-            SIDEBAR | SB => self.sidebars.push(String::from(item)),
+            DID | DI => {
+                self.did.push(String::from(item));
+                self.history.push(DID.to_string());
+            }
+            DOING | DO => {
+                self.doing.push(String::from(item));
+                self.history.push(DOING.to_string());
+            }
+            BLOCKER | BL => {
+                self.blockers.push(String::from(item));
+                self.history.push(BLOCKER.to_string());
+            }
+            SIDEBAR | SB => {
+                self.sidebars.push(String::from(item));
+                self.history.push(SIDEBAR.to_string());
+            }
             _ => println!("Not a valid command."),
         };
 
         data_file::write_to_file(file, self);
         print_standup_data(file)
     }
+
+    pub fn undo(mut self, file: &Path) {
+        match self.history.pop().expect("No history available").as_str() {
+            DID | DI => self.did.pop(),
+            DOING | DO => self.doing.pop(),
+            BLOCKER | BL => self.blockers.pop(),
+            SIDEBAR | SB => self.sidebars.pop(),
+            _ => Some("Invalid History".to_string()),
+        };
+
+        data_file::write_to_file(file, self);
+        print_standup_data(file)
+    }
 }
 
 // Clippy recommended I do this but I don't understand why yet.
